/*
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *  
 *  Copyright (C) 2000 - 2005 Liam Girdwood  
 */

#ifndef _LN_DYNAMICAL_TIME_H
#define _LN_DYNAMICAL_TIME_H

#include <libnova/ln_types.h>

#ifdef __cplusplus
extern "C" {
#endif

/*!
* \defgroup dynamical Dynamical Time
*
* TODO
*/

/*! \fn double ln_get_dynamical_time_diff (double JD)
* \ingroup dynamical
* \brief Calculate approximate dynamical time difference from julian day in seconds
*/
double LIBNOVA_EXPORT ln_get_dynamical_time_diff (double JD);

/*! \fn double ln_get_jde (double JD)
* \brief Calculate julian ephemeris day (JDE)
* \ingroup dynamical 
*/
double LIBNOVA_EXPORT ln_get_jde (double JD);
	
#ifdef __cplusplus
};
#endif

#endif
